# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options

__all__ = ["AuditsResource", "AsyncAuditsResource"]


class AuditsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AuditsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AuditsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuditsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AuditsResourceWithStreamingResponse(self)

    def request(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Initiates an AI-powered compliance audit for a specific period or scope,
        generating a comprehensive report detailing adherence to regulatory frameworks,
        internal policies, and flagging potential risks.
        """
        return self._post(
            "/corporate/compliance/audits",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncAuditsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAuditsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/diplomat-bit/aibank#accessing-raw-response-data-eg-headers
        """
        return AsyncAuditsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuditsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/diplomat-bit/aibank#with_streaming_response
        """
        return AsyncAuditsResourceWithStreamingResponse(self)

    async def request(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Initiates an AI-powered compliance audit for a specific period or scope,
        generating a comprehensive report detailing adherence to regulatory frameworks,
        internal policies, and flagging potential risks.
        """
        return await self._post(
            "/corporate/compliance/audits",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AuditsResourceWithRawResponse:
    def __init__(self, audits: AuditsResource) -> None:
        self._audits = audits

        self.request = to_raw_response_wrapper(
            audits.request,
        )


class AsyncAuditsResourceWithRawResponse:
    def __init__(self, audits: AsyncAuditsResource) -> None:
        self._audits = audits

        self.request = async_to_raw_response_wrapper(
            audits.request,
        )


class AuditsResourceWithStreamingResponse:
    def __init__(self, audits: AuditsResource) -> None:
        self._audits = audits

        self.request = to_streamed_response_wrapper(
            audits.request,
        )


class AsyncAuditsResourceWithStreamingResponse:
    def __init__(self, audits: AsyncAuditsResource) -> None:
        self._audits = audits

        self.request = async_to_streamed_response_wrapper(
            audits.request,
        )
