# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["CardIssueVirtualParams"]


class CardIssueVirtualParams(TypedDict, total=False):
    controls: Required[object]
    """Granular spending controls for a corporate card."""
